为了在重现过程中更易定位问题与更易开发维护，重现项目的部分功能与原始木兰可执行文件有区别。

- 部分报错信息改为中文包括表情符号等，但已知一些问题见 issue
- 支持中文命名标识符
- 引用（using）模块时，仅在木兰模块无法找到时退而寻找 python 模块；原始木兰中在引用木兰模块出错时不会报错而是直接寻找同名 python 模块
- 原始木兰使用系统默认编码读取源码，重现项目用UTF-8
- 生成木兰的 catch 时，重现项目成功；原始会报错 AttributeError: 'str' object has no attribute '_fields'
